@@ -382,6 +382,14 @@ print_version (void)
 #else
     g_print ("No\n");
 #endif
+
+    g_print ("\t- X Input 2 support:                            ");
+#ifdef HAVE_XI2
+    g_print ("Yes\n");
+#else
+    g_print ("No\n");
+#endif
+
     g_print ("\t- Embedded compositor:                          ");
 #ifdef HAVE_COMPOSITOR
     g_print ("Yes\n");
@@ -499,19 +507,7 @@ vblank_callback (const gchar  *name,
 
     return succeed;
 }
-#endif /* HAVE_COMPOSITOR */
 
-static gboolean
-daemon_callback (const gchar  *name,
-                 const gchar  *value,
-                 gpointer      user_data,
-                 GError      **error)
-{
-    g_warning ("Option 'daemon' is now removed and has no effect!");
-    return TRUE;
-}
-
-#ifdef HAVE_COMPOSITOR
 static gint
 init_compositor_display (DisplayInfo *display_info, gint compositor_mode)
 {
@@ -620,11 +616,13 @@ initialize (gint compositor_mode, gboolean replace_wm)
         else
         {
             /* create temp 1x1 child window on this screen */
-            temp_xwindow = XCreateSimpleWindow (display_info->dpy, RootWindow (display_info->dpy, i),
+            temp_xwindow = XCreateSimpleWindow (display_info->dpy,
+                                                RootWindow (display_info->dpy, i),
                                                 0, 0, 1, 1, 0, 0, 0);
             /* allocate new GdkWindow with GdkScreen for this window */
-            screen_window = gdk_x11_window_foreign_new_for_display (display_info->gdisplay,
-                                                                    temp_xwindow);
+            screen_window =
+                gdk_x11_window_foreign_new_for_display (display_info->gdisplay,
+                                                        temp_xwindow);
             XDestroyWindow (display_info->dpy, temp_xwindow);
 
             if (screen_window == NULL)
@@ -719,10 +717,11 @@ main (int argc, char **argv)
 #endif
     GOptionEntry option_entries[] =
     {
-        { "daemon", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, daemon_callback, N_("Fork to the background (not supported)"), NULL },
 #ifdef HAVE_COMPOSITOR
-        { "compositor", '\0', 0, G_OPTION_ARG_CALLBACK, compositor_callback, N_("Set the compositor mode"), "on|off|auto" },
-        { "vblank", '\0', 0, G_OPTION_ARG_CALLBACK, vblank_callback, N_("Set the vblank mode"), "off"
+        { "compositor", '\0', 0, G_OPTION_ARG_CALLBACK,
+          compositor_callback, N_("Set the compositor mode"), "on|off|auto" },
+        { "vblank", '\0', 0, G_OPTION_ARG_CALLBACK,
+          vblank_callback, N_("Set the vblank mode"), "off"
 #ifdef HAVE_PRESENT_EXTENSION
           "|xpresent"
 #endif /* HAVE_PRESENT_EXTENSION */
@@ -731,8 +730,10 @@ main (int argc, char **argv)
 #endif /* HAVE_EPOXY */
         },
 #endif /* HAVE_COMPOSITOR */
-        { "replace", '\0', 0, G_OPTION_ARG_NONE, &replace_wm, N_("Replace the existing window manager"), NULL },
-        { "version", 'V', 0, G_OPTION_ARG_NONE, &version, N_("Print version information and exit"), NULL },
+        { "replace", '\0', 0, G_OPTION_ARG_NONE,
+          &replace_wm, N_("Replace the existing window manager"), NULL },
+        { "version", 'V', 0, G_OPTION_ARG_NONE,
+          &version, N_("Print version information and exit"), NULL },
         { NULL }
     };
 
