@@ -188,6 +188,7 @@ struct _ScreenInfo
     Window root_overlay;
 #endif
     GList *cwindows;
+    GHashTable *cwindow_hash;
     Window output;
 
     gaussian_conv *gaussianMap;
@@ -209,6 +210,7 @@ struct _ScreenInfo
     gint cursorOffsetX;
     gint cursorOffsetY;
     XRectangle cursorLocation;
+    gboolean cursor_is_zoomed;
 
     guint wins_unredirected;
     gboolean compositor_active;
