@@ -745,6 +745,7 @@ loadSettings (ScreenInfo *screen_info)
         {"wrap_windows", NULL, G_TYPE_BOOLEAN, TRUE},
         {"wrap_workspaces", NULL, G_TYPE_BOOLEAN, TRUE},
         {"zoom_desktop", NULL, G_TYPE_BOOLEAN, TRUE},
+        {"zoom_pointer", NULL, G_TYPE_BOOLEAN, TRUE},
         {NULL, NULL, G_TYPE_INVALID, FALSE}
     };
 
@@ -849,6 +850,8 @@ loadSettings (ScreenInfo *screen_info)
         getBoolValue ("wrap_workspaces", rc);
     screen_info->params->zoom_desktop =
         getBoolValue ("zoom_desktop", rc);
+    screen_info->params->zoom_pointer =
+        getBoolValue ("zoom_pointer", rc);
 
     screen_info->params->wrap_layout =
         getBoolValue ("wrap_layout", rc);
@@ -1300,6 +1303,10 @@ cb_xfwm4_channel_property_changed(XfconfChannel *channel, const gchar *property_
                 {
                     screen_info->params->zoom_desktop = g_value_get_boolean (value);
                 }
+                else if (!strcmp (name, "zoom_pointer"))
+                {
+                    screen_info->params->zoom_pointer = g_value_get_boolean (value);
+                }
                 else if (!strcmp (name, "wrap_windows"))
                 {
                     screen_info->params->wrap_windows = g_value_get_boolean (value);
